﻿// ResticLogParser
// Copyright (C) 2025  Stefan Müller
//
// This program is free software: you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along with
// this program.  If not, see <http://www.gnu.org/licenses/>.

namespace ResticLogParser.src
{
    internal class DirectoryNode : IComparable<DirectoryNode>
    {
        private List<DirectoryNode> _children = new();

        public DirectoryNode(DirectoryNode? parent, string name, string fullName)
        {
            Parent = parent;
            Name = name;
            FullName = fullName;
            AddedSize = 0;
            FileCount = 0;
        }

        public DirectoryNode? Parent { get; private set; }

        public string Name { get; private set; }

        public string FullName { get; private set; }

        public long AddedSize { get; set; }

        public int FileCount { get; set; }

        public DirectoryNode? FindChild(string name)
        {
            return _children.Find(x => x.Name == name);
        }

        public DirectoryNode AddChild(string name, string fullName)
        {
            var node = new DirectoryNode(this, name, fullName);
            _children.Add(node);
            return node;
        }

        public int CompareTo(DirectoryNode? other)
        {
            if (other == null)
            {
                return 1;
            }

            int compare = AddedSize.CompareTo(other.AddedSize);
            if (compare != 0)
            {
                return compare;
            }

            return FileCount.CompareTo(other.FileCount);
        }

        public override string ToString()
        {
            return $"Added {AddedSize} bytes, {FileCount} files, {FullName}";
        }
    }
}
