﻿// ResticLogParser
// Copyright (C) 2025  Stefan Müller
//
// This program is free software: you can redistribute it and/or modify it under
// the terms of the GNU General Public License as published by the Free Software
// Foundation, either version 3 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along with
// this program.  If not, see <http://www.gnu.org/licenses/>.

using System.Globalization;

namespace ResticLogParser.src
{
    public class FileSize
    {
        public static long GetBytesFromString(string fileSizeText)
        {
            string[] split = fileSizeText.Split(" ", StringSplitOptions.TrimEntries);
            if (split.Length < 2 || split[0].Length < 1 || split[1].Length < 1 || split[1].Length > 3
                || split[1][split[1].Length - 1] != 'B')
            {
                return 0;
            }
            var value = double.Parse(split[0], CultureInfo.InvariantCulture.NumberFormat);
            var power = split[1].Length > 1
                ? split[1][0] switch
                    {
                        'K' => 1,
                        'M' => 2,
                        'G' => 3,
                        'T' => 4,
                        _ => 0
                    }
                : 0;

            int valueBase;
            if (split[1].Length < 3)
            {
                valueBase = 1000;
            }
            else if (split[1][1] == 'i')
            {
                valueBase = 1024;
            }
            else
            {
                return 0;
            }

            var s = Math.Pow(valueBase, power);
            var t = value * Math.Pow(valueBase, power);
            return (long)Math.Round(value * Math.Pow(valueBase, power));
        }
    }
}
